import { Optional } from "matrix-events-sdk";
import { AsyncStoreWithClient } from "./AsyncStoreWithClient";
import { ActionPayload } from "../dispatcher/payloads";
import { VoiceRecording } from "../audio/VoiceRecording";
interface IState {
    [roomId: string]: Optional<VoiceRecording>;
}
export declare class VoiceRecordingStore extends AsyncStoreWithClient<IState> {
    private static internalInstance;
    constructor();
    static get instance(): VoiceRecordingStore;
    protected onAction(payload: ActionPayload): Promise<void>;
    /**
     * Gets the active recording instance, if any.
     * @param {string} roomId The room ID to get the recording in.
     * @returns {Optional<VoiceRecording>} The recording, if any.
     */
    getActiveRecording(roomId: string): Optional<VoiceRecording>;
    /**
     * Starts a new recording if one isn't already in progress. Note that this simply
     * creates a recording instance - whether or not recording is actively in progress
     * can be seen via the VoiceRecording class.
     * @param {string} roomId The room ID to start recording in.
     * @returns {VoiceRecording} The recording.
     */
    startRecording(roomId: string): VoiceRecording;
    /**
     * Disposes of the current recording, no matter the state of it.
     * @param {string} roomId The room ID to dispose of the recording in.
     * @returns {Promise<void>} Resolves when complete.
     */
    disposeRecording(roomId: string): Promise<void>;
}
export {};
